@@ -1,6 +1,5 @@
 //! Object store-related code
 
-use crate::idb_query_source::IdbQuerySource;
 use wasm_bindgen::{prelude::*, JsCast};
 use web_sys::DomException;
 
@@ -101,12 +100,6 @@ impl IdbObjectStore<'_> {
         self.put_key_val(&key.into(), val)
     }
 
-    /// A list of the names of indices on objects in this object store.
-    #[inline]
-    pub fn index_names(&self) -> impl Iterator<Item = String> {
-        DomStringIterator::from(self.inner.index_names())
-    }
-
     /// The value of the auto increment flag for this object store.
     #[inline]
     pub fn auto_increment(&self) -> bool {
@@ -117,6 +110,14 @@ impl IdbObjectStore<'_> {
     cfg_if::cfg_if! {
         if #[cfg(feature = "indices")] {
 
+            /// A list of the names of indices on objects in this object store.
+            ///
+            /// Features required: `indices`
+            #[inline]
+            pub fn index_names(&self) -> impl Iterator<Item = String> {
+                DomStringIterator::from(self.inner.index_names())
+            }
+
             /// Create an index at the given key path
             ///
             /// Features required: `indices`
@@ -180,12 +181,6 @@ impl<'a> IdbObjectStore<'a> {
         &self.tx
     }
 
-    /// Delete this object store
-    #[inline]
-    pub fn delete_object_store(self) -> Result<(), DomException> {
-        self.db().delete_object_store(&self.name())
-    }
-
     /// Delete the record at the with the given key
     pub fn delete<K: JsCast>(&self, key: &K) -> Result<VoidRequest, DomException> {
         Ok(VoidRequest::new(self.inner.delete(key.unchecked_ref())?))
@@ -202,6 +197,7 @@ impl_query_source!(IdbObjectStore<'_>);
 
 #[cfg(test)]
 pub mod test {
+    use crate::idb_query_source::IdbQuerySource;
     use crate::internal_utils::open_any_db;
     use web_sys::IdbTransactionMode as TxMode;
     test_mod_init!();
